==> haskell-quickcheck-unicode-1.0.1.0-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-unicode
version: 1.0.1.0
id: quickcheck-unicode-1.0.1.0-76P5TNrbKrTFWIV3Zmj4kU
key: quickcheck-unicode-1.0.1.0-76P5TNrbKrTFWIV3Zmj4kU
license: BSD-2-Clause
copyright: 2014-2017 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/quickcheck-unicode
synopsis: Generator and shrink functions for testing
          Unicode-related software.
description:
    Generator and shrink functions for testing
    Unicode-related software.
category: Testing, Text
abi: acbf93a1fb743ec8492a7cc79930e925
exposed: True
exposed-modules:
    Test.QuickCheck.Unicode
import-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-unicode-1.0.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/quickcheck-unicode-1.0.1.0
hs-libraries: HSquickcheck-unicode-1.0.1.0-76P5TNrbKrTFWIV3Zmj4kU
depends:
    base-4.11.1.0 QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
haddock-interfaces: /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-unicode-1.0.1.0-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-unicode
version: 1.0.1.0
id: quickcheck-unicode-1.0.1.0-9CXrHSyFPuC9xe9j2mPdPV
key: quickcheck-unicode-1.0.1.0-9CXrHSyFPuC9xe9j2mPdPV
license: BSD-2-Clause
copyright: 2014-2017 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/quickcheck-unicode
synopsis: Generator and shrink functions for testing
          Unicode-related software.
description:
    Generator and shrink functions for testing
    Unicode-related software.
category: Testing, Text
abi: 1e49bafd49e8080138461af78c2e9606
exposed: True
exposed-modules:
    Test.QuickCheck.Unicode
import-dirs: /usr/lib/ghc-8.6.1/site-local/quickcheck-unicode-1.0.1.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/quickcheck-unicode-1.0.1.0
hs-libraries: HSquickcheck-unicode-1.0.1.0-9CXrHSyFPuC9xe9j2mPdPV
depends:
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
